#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-dbusmenugtk3
version:                0.4.15
visibility:             public
id:                     gi-dbusmenugtk3-0.4.15-GWYc7QlHjfD9jw77PvKZVq
key:                    gi-dbusmenugtk3-0.4.15-GWYc7QlHjfD9jw77PvKZVq
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               DbusmenuGtk bindings
description:            Bindings for libdbusgtk3, autogenerated by haskell-gi.
category:               Bindings
abi:                    1b8d041b64f194d6553758106434fa1a
exposed:                True
exposed-modules:
    GI.DbusmenuGtk3 GI.DbusmenuGtk3.Config GI.DbusmenuGtk3.Constants
    GI.DbusmenuGtk3.Functions GI.DbusmenuGtk3.Objects
    GI.DbusmenuGtk3.Objects.Client GI.DbusmenuGtk3.Objects.Menu

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-dbusmenugtk3-0.4.15
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-dbusmenugtk3-0.4.15 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-dbusmenugtk3-0.4.15 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-dbusmenugtk3
hs-libraries:           HSgi-dbusmenugtk3-0.4.15-GWYc7QlHjfD9jw77PvKZVq
extra-libraries:
    dbusmenu-gtk3 dbusmenu-glib gtk-3 gdk-3 pangocairo-1.0
    cairo-gobject gdk_pixbuf-2.0 atk-1.0 pango-1.0 cairo harfbuzz
    gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    dbusmenu-gtk3 dbusmenu-glib gtk-3 gdk-3 pangocairo-1.0 m Xrandr
    Xcursor Xcomposite Xdamage Xinerama cloudproviders cairo-gobject m
    dl gdk_pixbuf-2.0 m glycin-2 seccomp lcms2 pthread atk-bridge-2.0
    atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd xkbcommon
    wayland-cursor wayland-egl wayland-client m rt epoxy dl GL EGL
    pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m dl
    fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype dl
    bz2 png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0
    ffi gmodule-2.0 glib-2.0 atomic m pcre2-8 pthread z mount blkid
    sysprof-capture-4

include-dirs:
    /usr/include/libdbusmenu-gtk3-0.4 /usr/include/libdbusmenu-glib-0.4
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-atk-2.0.28-F4FBvs1Eed93YqyPKBoPOX
    gi-dbusmenu-0.4.14-4419mmwLKin2LDEJZ1sYNd
    gi-gdk-3.0.29-DPnjfGERStQGp1Abc4KUTT
    gi-gdkpixbuf-2.0.32-A14sjQcFTy04ZNPyg29QqA
    gi-glib-2.0.30-GQdzVbXRko071pCrqOIWOd
    gi-gobject-2.0.31-JrRju07j0QqF7a6qbUhWpF
    gi-gtk-3.0.43-LpFnXRJkNsSAoaQJNmVfgd
    haskell-gi-0.26.16-DT0fMT4725hIpjqfyuoqdQ
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-gi-dbusmenugtk3/html/gi-dbusmenugtk3.haddock

haddock-html:           /usr/share/doc/haskell-gi-dbusmenugtk3/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

